# 网页微信（WebWeChat）

## 项目简介
本项目基于Spring Boot框架，通过Gewechat技术实现网页版微信功能。支持用户登录、消息收发、联系人管理、群组操作等功能，提供Web端微信使用体验。

## 功能模块
- **用户登录**：通过微信扫码登录，支持回调验证
- **消息系统**：实现消息的发送、接收与展示
- **联系人管理**：支持好友、群组信息的查询与维护
- **文件传输**：集成文件下载功能（通过DownloadApi）
- **个性化设置**：标签管理和收藏功能（FavorApi、LabelApi）

## 技术栈
- **后端**：Java 8+, Spring Boot 2.x
- **HTTP客户端**：OkHttp
- **前端**：HTML5 + CSS3（使用Thymeleaf模板）
- **API模块化**：分层设计（Controller-Service-Api）
- **配置管理**：Spring Boot application.yml

## 目录结构
```
src/
├── main/
│   ├── java/
│   │   └── com.hokori.webwx/
│   │       ├── Api          # 微信API接口实现
│   │       ├── Controller   # Web控制器层
│   │       ├── Service      # 业务逻辑层
│   │       └── util         # 工具类
│   └── resources/
│       ├── static/          # 前端静态资源（CSS/JS）
│       └── templates/       # Thymeleaf模板页面
└── test/                    # 单元测试
```

## 快速开始
### 环境要求
- JDK 8+
- Maven 3.6+
- MySQL（如需持久化，需配置application.yml）

### 运行步骤
1. 克隆项目
```bash
git clone https://github.com/your-repo/webwx.git
```

2. 构建项目
```bash
mvn clean package
```

3. 启动应用
```bash
mvn spring-boot:run
```

4. 访问地址
```bash
http://localhost:8080/login
```

## 使用说明
1. 访问登录页面扫码登录微信
2. 登录成功后跳转至聊天界面
3. 支持：
   - 好友消息实时推送
   - 文件下载（通过文件链接）
   - 群组消息管理
   - 联系人信息查看

## API文档
主要API接口位于`com.hokori.webwx.Api`包：
- **LoginApi**：微信登录验证
- **MessageApi**：消息收发核心接口
- **GroupApi**：群组管理功能
- **DownloadApi**：文件下载服务

## 贡献指南
1. Fork项目
2. 创建功能分支：`git checkout -b feature/X`
3. 提交修改：`git commit -m 'Add some feature'`
4. Push到分支：`git push origin feature/X`
5. 提交Pull Request

## 问题反馈
遇到问题请提交Issue，说明：
- 操作步骤
- 错误截图
- 环境配置