package com.hokori.webwx.Controller;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.jackson.JsonObjectSerializer;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.json.JSONArray;
import org.json.JSONObject;

import com.hokori.webwx.Api.ck;
import com.hokori.webwx.Api.base.LoginApi;
import com.hokori.webwx.Service.ChatService;
import com.hokori.webwx.Service.LoginService;

import jakarta.servlet.http.Cookie;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

@Controller
public class LoginController {

    @Autowired
    private LoginService loginService;

    @Autowired
    private ck loginck;

    @Autowired
    private ChatService chatService;
    
    @GetMapping("/")
    public String index(HttpServletRequest request) {
        // 检查Cookie中是否存在deviceId
        Cookie[] cookies = request.getCookies();
        if (cookies != null) {
            for (Cookie cookie : cookies) {
                if ("deviceId".equals(cookie.getName())) {
                    String deviceId = cookie.getValue();
                    // 验证设备是否已登录
                    String deviceListJson = loginService.usaerList();
                    try {
                        // 解析JSON字符串
                        JSONObject jsonObject = new JSONObject(deviceListJson);
                        JSONArray devicesArray = jsonObject.getJSONArray("devices");
                        
                        // 检查设备是否已登录
                        for (int i = 0; i < devicesArray.length(); i++) {
                            JSONObject device = devicesArray.getJSONObject(i);
                            if (device.getString("device").equals(deviceId) && device.getBoolean("isLogin")) {
                                // 设备已登录，重定向到聊天页面
                                return "redirect:/chat";
                            }
                        }
                    } catch (Exception e) {
                        // 解析失败，重定向到登录页面
                        return "redirect:/login";
                    }
                    break;
                }
            }
        }
        
        // 如果没有Cookie或设备未登录，重定向到登录页面
        return "redirect:/login";
    }

    @GetMapping("/chat")
    public String chat(Model model,HttpServletRequest request) {
        Cookie[] cookies = request.getCookies();
        String tx = "";
        if (cookies!= null) {
            for (Cookie cookie : cookies) {
                if ("deviceId".equals(cookie.getName())) {
                    String deviceId = cookie.getValue();
                    // 验证设备是否已登录
                    Boolean isLogin = loginck.checkOnline(deviceId);
                    if (isLogin) {
                        // 设备已登录，获取用户头像
                        tx = chatService.getUser(deviceId);
                        // 将tx添加到Model中以便模板使用
                        model.addAttribute("tx", tx);
                        return "chat";
                    } else {
                        // 设备未登录，重定向到登录页面
                        return "redirect:/login";
                    }
                }
            }   
        }else{
            // 设备未登录，重定向到登录页面
            return "redirect:/login";
        }

        model.addAttribute("tx", tx);
        return "chat";
    }
    
    @GetMapping("/login")
    public String login(Model model, HttpServletRequest request) {
        // 检查Cookie中是否存在deviceId
        Cookie[] cookies = request.getCookies();
        if (cookies != null) {
            for (Cookie cookie : cookies) {
                if ("deviceId".equals(cookie.getName())) {
                    String deviceId = cookie.getValue();
                    // 验证设备是否已登录
                    String deviceListJson = loginService.usaerList();
                    try {
                        // 解析JSON字符串
                        JSONObject jsonObject = new JSONObject(deviceListJson);
                        JSONArray devicesArray = jsonObject.getJSONArray("devices");
                        
                        // 检查设备是否已登录
                        for (int i = 0; i < devicesArray.length(); i++) {
                            JSONObject device = devicesArray.getJSONObject(i);
                            if (device.getString("device").equals(deviceId) && device.getBoolean("isLogin")) {
                                // 设备已登录，重定向到根路径
                                return "redirect:/";
                            }
                        }
                    } catch (Exception e) {
                        // 解析失败，继续显示登录页面
                    }
                    break;
                }
            }
        }
        
        // 如果没有Cookie或设备未登录，显示登录页面
        // 调用LoginService的usaerList方法获取设备列表数据
        String deviceListJson = loginService.usaerList();
        
        try {
            // 解析JSON字符串
            JSONObject jsonObject = new JSONObject(deviceListJson);
            JSONArray devicesArray = jsonObject.getJSONArray("devices");
            
            // 将JSON数组转换为Model属性
            model.addAttribute("devices", devicesArray.toList());
        } catch (Exception e) {
            // 添加一个空列表，避免模板渲染错误
            model.addAttribute("devices", new JSONArray().toList());
        }
        
        return "login";
    }
    
    @GetMapping("/qrlogin")
    public String qrlogin(Model model, HttpServletRequest request) {
       JSONObject req = new JSONObject(loginService.newlogin());
       
       // 从返回的JSON中获取data字段，它是一个JSONObject而不是JSONArray
       JSONObject data = req.getJSONObject("data");
       
       // 直接从data对象中提取所需的三个值
       try {
           String uuid = data.getString("uuid");
           String appId = data.getString("appId");
           String qrImgBase64 = data.getString("qrImgBase64");
           
           // 将值添加到Model中供前端使用
           model.addAttribute("uuid", uuid);
           model.addAttribute("appId", appId);
           model.addAttribute("qrCodeBase64", qrImgBase64);
       } catch (Exception e) {
           // 如果获取失败，可以记录错误日志
           // log.error("获取登录二维码数据失败", e);
       }

        return "qrlogin";
    }

    @PostMapping("/api/checklogin")
    public ResponseEntity<String> checkLogin(@RequestParam String appid, @RequestParam String uuid, HttpServletResponse response) {
        JSONObject loginJson = new JSONObject(loginService.ckqr(appid, uuid));

        return ResponseEntity.ok(loginJson.toString());
    }
    /**
     * 处理设备登录并设置Cookie
     * @param deviceId 设备ID
     * @param response HTTP响应对象
     * @return 登录结果
     */
    @PostMapping("/api/login")
    @ResponseBody
    public ResponseEntity<String> processLogin(@RequestParam String deviceId, HttpServletResponse response) {
        // 验证设备是否存在且已登录
        String deviceListJson = loginService.usaerList();
        boolean isValidDevice = false;
        
        try {
            // 解析JSON字符串
            JSONObject jsonObject = new JSONObject(deviceListJson);
            JSONArray devicesArray = jsonObject.getJSONArray("devices");
            
            // 使用流处理JSON数组
            for (int i = 0; i < devicesArray.length(); i++) {
                JSONObject device = devicesArray.getJSONObject(i);
                if (device.getString("device").equals(deviceId) && device.getBoolean("isLogin")) {
                    isValidDevice = true;
                    break;
                }
            }
        } catch (Exception e) {
            return ResponseEntity.badRequest().body("解析设备数据失败");
        }
        
        if (isValidDevice) {
            // 创建Cookie并设置
            Cookie deviceCookie = new Cookie("deviceId", deviceId);
            deviceCookie.setPath("/");
            deviceCookie.setMaxAge(7 * 24 * 60 * 60); // 设置Cookie有效期为7天
            response.addCookie(deviceCookie);
            
            return ResponseEntity.ok("登录成功");
        } else {
            return ResponseEntity.badRequest().body("设备未登录或不存在");
        }
    }
}