package com.hokori.webwx.Service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.hokori.webwx.Api.base.LoginApi;
import com.hokori.webwx.Api.base.PersonalApi;
import com.hokori.webwx.Service.LoginService;

import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.List;
import com.alibaba.fastjson2.JSONObject;
import com.alibaba.fastjson2.JSONArray;

@Service
@Slf4j
public class LoginServiceImpl implements LoginService {

    
    @Override
    public String usaerList() {
        log.info("调用设备列表接口");
        JSONObject dlistJson = LoginApi.devicelist();
        
        List<String> deviceList = new ArrayList<>();
        JSONArray resultArray = new JSONArray();
        
        try {
            if (dlistJson != null && dlistJson.getIntValue("ret") == 200) {
                JSONArray dataArray = dlistJson.getJSONArray("data");
                if (dataArray != null) {
                    for (int i = 0; i < dataArray.size(); i++) {
                        deviceList.add(dataArray.getString(i));
                    }
                }
            } else {
                log.error("获取设备列表失败: {}", dlistJson != null ? dlistJson.toJSONString() : "null");
            }

            for (String device : deviceList) {
                log.info("获取设备 {} 的信息", device);
                JSONObject profileJson = PersonalApi.getProfile(device);
                String nikname = "";
                String smallHeadImgUrl = "";
                if (profileJson != null && profileJson.getIntValue("ret") == 200) {
                    JSONObject data = profileJson.getJSONObject("data");
                    if (data != null) {
                        log.info("获取昵称和头像");
                        nikname = data.getString("nickName");
                        smallHeadImgUrl = data.getString("smallHeadImgUrl");
                    }
                } else {
                    log.error("获取设备 {} 的 Profile 失败: {}", device, profileJson != null ? profileJson.toJSONString() : "null");
                }

                JSONObject onlineJson = LoginApi.checkOnline(device);
                boolean isLogin = false;
                if (onlineJson != null && onlineJson.getIntValue("ret") == 200) {
                    isLogin = onlineJson.getBooleanValue("data");
                } else {
                     log.error("检查设备 {} 在线状态失败: {}", device, onlineJson != null ? onlineJson.toJSONString() : "null");
                }
                
                // 创建设备信息的JSON对象
                JSONObject deviceInfo = new JSONObject();
                deviceInfo.put("device", device);
                deviceInfo.put("smallHeadImgUrl", smallHeadImgUrl);
                deviceInfo.put("nikname", nikname);
                deviceInfo.put("isLogin", isLogin);
                
                // 添加到结果数组
                resultArray.add(deviceInfo);
            }
        } catch (Exception e) {
            log.error("处理设备列表数据失败", e);
        }
        
        // 将结果数组包装到一个JSON对象中并返回字符串
        JSONObject result = new JSONObject();
        result.put("devices", resultArray);
        return result.toJSONString();
    }

    public String newlogin() {
        JSONObject loginJson = LoginApi.getQr(null);
        if (loginJson != null && loginJson.getIntValue("ret") == 200) {
            return loginJson.toJSONString();
        } else {
            log.error("获取登录二维码失败: {}", loginJson!= null? loginJson.toJSONString() : "null");
            return "获取登录二维码失败";
        }
    }

    public String relogin(String appid) {
        JSONObject loginJson = LoginApi.getQr(appid);
        if (loginJson != null && loginJson.getIntValue("ret") == 200) {
            return loginJson.toJSONString();
        } else {
            log.error("获取登录二维码失败: {}", loginJson!= null? loginJson.toJSONString() : "null");
            return "获取登录二维码失败";
        }
    }

    public String ckqr(String appid, String uuid) {

        JSONObject loginJson = LoginApi.checkQr(appid, uuid, null);
        if (loginJson!= null && loginJson.getIntValue("ret") == 200) {
            return loginJson.toJSONString();
        } else {
            log.error("登录失败: {}", loginJson!= null? loginJson.toJSONString() : "null");
            return loginJson.toJSONString();
        }

    }
}

