package com.hokori.webwx.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;

// 使用 @JsonIgnoreProperties(ignoreUnknown = true) 避免因为 Gewechat 发送了未定义的字段而导致反序列化失败
@JsonIgnoreProperties(ignoreUnknown = true)
public class GewechatMessage {

    // 假设 Gewechat 发送的消息 ID 字段名为 messageId 或 msgId
    @JsonProperty("messageId") // 如果 Gewechat 的字段名不同，请修改这里，例如 @JsonProperty("msg_id")
    private String messageId;

    // 假设发送者 ID 字段名为 senderId 或 from_wxid
    @JsonProperty("senderId")
    private String senderId;

    // 假设接收者 ID 字段名为 receiverId 或 to_wxid (通常是机器人自己的 WxID)
    @JsonProperty("receiverId")
    private String receiverId;

    // 假设群聊 ID 字段名为 roomId 或 room_wxid (如果是群消息)
    @JsonProperty("roomId")
    private String roomId;

    // 假设消息内容字段名为 content 或 text
    @JsonProperty("content")
    private String content;

    // 假设消息类型字段名为 messageType 或 type (例如：text, image, voice, video, file, system...)
    @JsonProperty("messageType")
    private String messageType;

    // 假设时间戳字段名为 timestamp (可能是 long 或 String)
    @JsonProperty("timestamp")
    private Long timestamp;

    // 可以根据需要添加更多字段，例如：
    // @JsonProperty("senderNickname")
    // private String senderNickname;
    //
    // @JsonProperty("isGroupMessage")
    // private boolean isGroupMessage;

    // --- Getters and Setters ---

    public String getMessageId() {
        return messageId;
    }

    public void setMessageId(String messageId) {
        this.messageId = messageId;
    }

    public String getSenderId() {
        return senderId;
    }

    public void setSenderId(String senderId) {
        this.senderId = senderId;
    }

    public String getReceiverId() {
        return receiverId;
    }

    public void setReceiverId(String receiverId) {
        this.receiverId = receiverId;
    }

    public String getRoomId() {
        return roomId;
    }

    public void setRoomId(String roomId) {
        this.roomId = roomId;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getMessageType() {
        return messageType;
    }

    public void setMessageType(String messageType) {
        this.messageType = messageType;
    }

    public Long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Long timestamp) {
        this.timestamp = timestamp;
    }

    // --- toString() for logging ---

    @Override
    public String toString() {
        return "GewechatMessage{" +
                "messageId='" + messageId + '\'' +
                ", senderId='" + senderId + '\'' +
                ", receiverId='" + receiverId + '\'' +
                ", roomId='" + roomId + '\'' +
                ", content='" + content + '\'' +
                ", messageType='" + messageType + '\'' +
                ", timestamp=" + timestamp +
                '}';
    }
}
